@@ -37,11 +37,11 @@ def bapi_return(value):
     """Log any contents of BAPIRET2 depending on log level. Returning Exception if 'E' or 'A'."""
     if not isinstance(value, list):
         value = [value,]
-    result = None
+    result = []
     messages = []
     for i in value:
         if i.type in ('E', 'A'):
-            result = BapiException(i, messages)
+            result.append(BapiException(i, messages))
         messages.append(i)
         logger.log(*format_bapi_return(i))
     return result
